@@ -9,6 +9,7 @@ class Map(Enum):
                "CLASSIC",
                Developer.Luminous,
                ["Base.SC2Data/GameData/Terrain/Classic.xml"],
+               "maps/classic.SC2Map",
                False,
                None)
     Duck_Map = (1,
@@ -16,6 +17,7 @@ class Map(Enum):
                 "DUCK_MAP",
                 Developer.Duck,
                 ["Base.SC2Data/GameData/Terrain/DuckMap.xml"],
+                "maps/duck_map.SC2Map",
                 True,
                 None)
     Four_Seasons = (2,
@@ -23,6 +25,7 @@ class Map(Enum):
                     "ZERUS_VOLCANOES",
                     Developer.Luminous,
                     ["Base.SC2Data/GameData/Terrain/FourSeasons.xml"],
+                    "maps/four_seasons.SC2Map",
                     True,
                     None)
     Zerus_Volcanoes = (3,
@@ -30,6 +33,7 @@ class Map(Enum):
                        "FOUR_SEASONS",
                        Developer.Luminous,
                        ["Base.SC2Data/GameData/Terrain/ZerusVolcanoes.xml"],
+                       "maps/zerus_volcanoes.SC2Map",
                        True,
                        None)
     Ruins_Of_Imladoon = (4,
@@ -37,6 +41,7 @@ class Map(Enum):
                          "RUINS_OF_IMLADOON",
                          Developer.Fatline,
                          ["Base.SC2Data/GameData/Terrain/RuinsOfImladoon.xml"],
+                         "maps/ruins_of_imladoon.SC2Map",
                          True,
                          Developer.Templar)
     Heart_Of_Amethyst = (5,
@@ -44,6 +49,7 @@ class Map(Enum):
                          "HEART_OF_AMETHYST",
                          Developer.Luminous,
                          ["Base.SC2Data/GameData/Terrain/HeartOfAmethyst.xml"],
+                         "maps/heart_of_amethyst.SC2Map",
                          False,
                          None)
     Vintage_Shores = (6,
@@ -51,6 +57,7 @@ class Map(Enum):
                       "VINTAGE_SHORES",
                       Developer.Templar,
                       ["Base.SC2Data/GameData/Terrain/VintageShores.xml"],
+                      "maps/vintage_shores.SC2Map",
                       False,
                       None)
     Aiur_Fountains = (7,
@@ -58,6 +65,7 @@ class Map(Enum):
                       "AIUR_FOUNTAINS",
                       Developer.Luminous,
                       ["Base.SC2Data/GameData/Terrain/AiurFountains.xml"],
+                      "maps/aiur_fountains.SC2Map",
                       False,
                       None)
     Kaldir_Cliffs = (8,
@@ -65,6 +73,7 @@ class Map(Enum):
                      "KALDIR_CLIFFS",
                      Developer.Understudy,
                      ["Base.SC2Data/GameData/Terrain/KaldirCliffs.xml"],
+                     "maps/kaldir_cliffs.SC2Map",
                      True,
                      None)
 
@@ -75,12 +84,14 @@ class Map(Enum):
                  galaxy_representation: str,
                  original_author: Developer,
                  custom_file_list: list[str],
+                 file_path: str,
                  map_available: bool = False,
                  current_author: Developer = None):
         self._index = index
         self._name_dict = name_dict
         self._galaxy_representation = galaxy_representation
         self._custom_file_list = custom_file_list
+        self._file_path = file_path
         self._original_author = original_author
         self._current_author = original_author if current_author is None else current_author
         self._map_available = map_available
@@ -107,6 +118,9 @@ class Map(Enum):
     def current_author(self):
         return self._current_author
 
+    def file_path(self):
+        return self._file_path
+
     def is_map_available(self):
         return self._map_available
 
